@@ -13,12 +13,21 @@
 
 import hildon
 import gtk
+import os
+import sys
 from threading import Thread
 
-from KeyMappings import mappingA, mappingB, mappingC, mappingD, altMappingA, altMappingB, altMappingC, altMappingD
+from KeyMappings import *
 from XControl import XControl
 from Zeemote import ZeeDiscover, Zeemote, buttonmap
 
+# If a user config directoryis present try to load mappings
+# from there.
+userConfigPath = os.getenv("HOME") + "/.zeecontrol"
+if os.path.isdir(userConfigPath):
+  sys.path.append(userConfigPath)
+  from UserMappings import *
+
 pressed={
     'A': [False],
     'B': [False],
@@ -33,7 +42,6 @@ pressed={
 # Set defaults.
 mapping = mappingA
 altMapping = altMappingA
-useAlt = False
 
 class ZeecontrolGUI(hildon.Program):
   def __init__(self):
@@ -148,46 +156,46 @@ class ZeemoteEventThread(Thread):
       #X is positive
       if gx > TOLERANCE and not xpon:
         xpon = True
-        self.control.ExecuteScript(mapping["GU"])               
+        self.control.executeScript(mapping["GU"])               
       if xpon and gx < TOLERANCE and gx > -TOLERANCE:
         xpon = False
-        self.control.ExecuteReleasedScript(mapping["GU"])
+        self.control.executeReleasedScript(mapping["GU"])
       #X is negative
       if gx < -TOLERANCE and not xnon:
         xnon = True
-        self.control.ExecuteScript(mapping["GD"])
+        self.control.executeScript(mapping["GD"])
       if xnon and gx < TOLERANCE and gx > -TOLERANCE:
         xnon = False
-        self.control.ExecuteReleasedScript(mapping["GD"])
+        self.control.executeReleasedScript(mapping["GD"])
              
       #Y is positive
       if gy > TOLERANCE and not ypon:
         ypon = True
-        self.control.ExecuteScript(mapping["GL"])
+        self.control.executeScript(mapping["GL"])
       if ypon and gy < TOLERANCE and gy > -TOLERANCE:
         ypon = False
-        self.control.ExecuteReleasedScript(mapping["GL"])
+        self.control.executeReleasedScript(mapping["GL"])
       #Y is negative
       if gy < -TOLERANCE and not ynon:
         ynon = True
-        self.control.ExecuteScript(mapping["GR"])
+        self.control.executeScript(mapping["GR"])
       if ynon and gy < TOLERANCE and gy > -TOLERANCE:
         ynon = False
-        self.control.ExecuteReleasedScript(mapping["GR"])
+        self.control.executeReleasedScript(mapping["GR"])
 
       buttonmask = state.getButtonMask()
       for bb in buttons:
         if (buttonmask & buttonmap[bb]):          
-          if useAlt:
-            self.control.ExecuteScript(altMapping[bb])
+          if useAlt and buttonmap & buttonmap[altButton]:
+            self.control.executeScript(altMapping[bb])
             pressed[bb]=True                      
           else:
-            self.control.ExecuteScript(mapping[bb])
+            self.control.executeScript(mapping[bb])
             pressed[bb]=True
         elif (not (buttonmask & buttonmap[bb])):
           if pressed[bb]==True:
             pressed[bb]=False                          
-            self.control.ExecuteReleasedScript(mapping[bb])
+            self.control.executeReleasedScript(mapping[bb])
 
       while gtk.events_pending():
       	gtk.main_iteration()                
